@@ -34,6 +34,7 @@ class FileCurrenciesRepository(CurrenciesRepositoryInterface):
     PARAMETER_NAME = "name"
     PARAMETER_SS58_FORMAT = "ss58_format"
     PARAMETER_ENTRY_POINTS = "entry_points"
+    PARAMETER_GENESIS_HASH = "genesis_hash"
 
     filepath = None
 
@@ -57,6 +58,7 @@ class FileCurrenciesRepository(CurrenciesRepositoryInterface):
             code_name,
             parameters[self.PARAMETER_NAME],
             parameters[self.PARAMETER_SS58_FORMAT],
+            genesis_hash=parameters[self.PARAMETER_GENESIS_HASH],
         )
 
     def code_names(self) -> list:
