@@ -16,10 +16,9 @@ from typing import Any, Dict, List, Optional
 from uuid import UUID
 
 from tikka.domains.currencies import Currencies
-from tikka.domains.entities.account import Account, AccountCryptoType
+from tikka.domains.entities.account import Account, AccountBalance, AccountCryptoType
 from tikka.domains.entities.constants import DERIVATION_SCAN_MAX_NUMBER
 from tikka.domains.entities.events import AccountEvent, LastTransferEvent
-from tikka.domains.entities.identity import Identity
 from tikka.domains.events import EventDispatcher
 from tikka.domains.passwords import Passwords
 from tikka.domains.transfers import Transfers
@@ -254,7 +253,15 @@ class Accounts:
         :param account: Account instance
         :return:
         """
-        account.balance = self.network_node.get_balance(account.address)
+        account_balance = self.network_node.get_balance(account.address)
+        if account_balance is not None:
+            account.balance = account_balance.total
+            account.balance_available = account_balance.available
+            account.balance_reserved = account_balance.reserved
+        else:
+            account.balance = None
+            account.balance_available = None
+            account.balance_reserved = None
         self.repository.update(account)
 
         return account
@@ -269,7 +276,15 @@ class Accounts:
         :param account: Account instance
         :return:
         """
-        account.balance = self.network_node.get_balance(account.address)
+        account_balance = self.network_node.get_balance(account.address)
+        if account_balance is not None:
+            account.balance = account_balance.total
+            account.balance_available = account_balance.available
+            account.balance_reserved = account_balance.reserved
+        else:
+            account.balance = None
+            account.balance_available = None
+            account.balance_reserved = None
         self.repository.update(account)
 
         return account
@@ -285,19 +300,28 @@ class Accounts:
             [account.address for account in accounts]
         )
         for account in accounts:
-            account.balance = balances[account.address]
+            if balances[account.address] is not None:
+                account.balance = balances[account.address].total  # type: ignore
+                account.balance_available = balances[account.address].available  # type: ignore
+                account.balance_reserved = balances[account.address].reserved  # type: ignore
+            else:
+                account.balance = None
+                account.balance_available = None
+                account.balance_reserved = None
             self.repository.update(account)
 
-    def network_get_balance(self, address: str) -> Optional[int]:
+    def network_get_balance(self, address: str) -> Optional[AccountBalance]:
         """
-        Return account balance from network
+        Return AccountBalance instance from network
 
         :param address: Account address
         :return:
         """
         return self.network_node.get_balance(address)
 
-    def network_get_balances(self, addresses: List[str]) -> Dict[str, Optional[int]]:
+    def network_get_balances(
+        self, addresses: List[str]
+    ) -> Dict[str, Optional[AccountBalance]]:
         """
         Return balances of address list from network
 
@@ -306,17 +330,6 @@ class Accounts:
         """
         return self.network_node.get_balances(addresses)
 
-    def network_get_unclaimed_ud_balance(self, identity: Identity) -> int:
-        """
-        Return the unclaimed UD balance of identity from network
-
-        :param identity: Identity instance
-        :return:
-        """
-        balance = self.network_node.get_unclaimed_ud_balance(identity.first_eligible_ud)
-
-        return balance
-
     def network_update_total_transfers_count(self, account: Account) -> Account:
         """
         Update account total_transfers_count from network
