@@ -31,6 +31,7 @@ from tikka.domains.categories import Categories
 from tikka.domains.config import Config
 from tikka.domains.connections import Connections
 from tikka.domains.currencies import Currencies
+from tikka.domains.datapods import DataPods
 from tikka.domains.entities.account import Account
 from tikka.domains.entities.category import Category
 from tikka.domains.entities.constants import DATABASE_FILE_EXTENSION, LOCALES_PATH
@@ -45,6 +46,7 @@ from tikka.domains.indexers import Indexers
 from tikka.domains.nodes import Nodes
 from tikka.domains.passwords import Passwords
 from tikka.domains.preferences import Preferences
+from tikka.domains.profiles import Profiles
 from tikka.domains.smiths import Smiths
 from tikka.domains.technical_committee import TechnicalCommittee
 from tikka.domains.transfers import Transfers
@@ -121,6 +123,9 @@ class Application:
             self.network.indexer.transfers,
             self.event_dispatcher,
         )
+        self.profiles = Profiles(
+            self.repository.profiles, self.network.datapod.profiles, self.currencies
+        )
         self.identities = Identities(
             self.repository.identities,
             self.network.node.identities,
@@ -150,7 +155,13 @@ class Application:
             self.repository.indexers,
             self.preferences,
             self.network.indexer,
-            self.config,
+            self.currencies,
+            self.event_dispatcher,
+        )
+        self.datapods = DataPods(
+            self.repository.datapods,
+            self.preferences,
+            self.network.datapod,
             self.currencies,
             self.event_dispatcher,
         )
