@@ -91,6 +91,7 @@ class Connections(ConnectionsInterface):
 
         self._node = self.network.node.connection
         self._indexer = self.network.indexer.connection
+        self._datapod = self.network.datapod.connection
 
     @property
     def node(self) -> ConnectionInterface:
@@ -106,15 +107,27 @@ class Connections(ConnectionsInterface):
         )
         return self._indexer
 
+    @property
+    def datapod(self) -> ConnectionInterface:
+        __doc__ = (  # pylint: disable=redefined-builtin, unused-variable
+            ConnectionsInterface.datapod.__doc__
+        )
+        return self._datapod
+
     def disconnect_all(self):
         __doc__ = (  # pylint: disable=redefined-builtin, unused-variable
             ConnectionsInterface.disconnect_all.__doc__
         )
         self.node.disconnect()
         self.indexer.disconnect()
+        self.datapod.disconnect()
 
     def are_all_connected(self) -> bool:
         __doc__ = (  # pylint: disable=redefined-builtin, unused-variable
             ConnectionsInterface.are_all_connected.__doc__
         )
-        return self.node.is_connected() and self.indexer.is_connected()
+        return (
+            self.node.is_connected()
+            and self.indexer.is_connected()
+            and self.datapod.is_connected()
+        )
