@@ -114,5 +114,9 @@ class Currencies:
         :return:
         """
         currency = self.network.get_instance()
+        if currency.genesis_hash != self.get_current().genesis_hash:
+            raise Exception(
+                "currencies.network_update_properties: Node genesis hash is different!"
+            )
         self.currency_repository.update(currency)
         self.set_current(currency.code_name)
