@@ -99,28 +99,28 @@ class Passwords:
         """
         self.repository.add(password)
 
-    def get(self, root: str) -> Optional[Password]:
+    def get(self, root_address: str) -> Optional[Password]:
         """
         Return Password instance from root address
 
-        :param root: Root address
+        :param root_address: Root address
         :return:
         """
-        return self.repository.get(root)
+        return self.repository.get(root_address)
 
-    def get_clear_password(self, keypair: Keypair) -> Optional[str]:
+    def get_clear_password(self, root_keypair: Keypair) -> Optional[str]:
         """
         Get clear password from Keypair
 
-        :param keypair: Keypair of root account
+        :param root_keypair: Keypair of root account
         :return:
         """
-        password = self.get(keypair.ss58_address)
+        password = self.get(root_keypair.ss58_address)
         if password is None:
             return None
         key = scrypt(
-            keypair.private_key.hex(),
-            keypair.public_key.hex(),
+            root_keypair.private_key.hex(),
+            root_keypair.public_key.hex(),
             Passwords.chacha_key_length,
             Passwords.scrypt_n,
             Passwords.scrypt_r,
@@ -144,14 +144,14 @@ class Passwords:
         """
         self.repository.update(password)
 
-    def delete(self, root: str) -> None:
+    def delete(self, root_address: str) -> None:
         """
         Delete password in repository
 
-        :param root: Root address of password to delete
+        :param root_address: Root address of password to delete
         :return:
         """
-        self.repository.delete(root)
+        self.repository.delete(root_address)
 
     def delete_all(self) -> None:
         """
@@ -161,14 +161,14 @@ class Passwords:
         """
         self.repository.delete_all()
 
-    def exists(self, root: str) -> bool:
+    def exists(self, root_address: str) -> bool:
         """
         Return True if password with root address exists in repository
 
-        :param root: Root address to check
+        :param root_address: Root address to check
         :return:
         """
-        return self.repository.exists(root)
+        return self.repository.exists(root_address)
 
     def list(self) -> List[Password]:
         """
