@@ -15,7 +15,7 @@
 
 import abc
 
-from tikka.domains.entities.node import Node
+from tikka.interfaces.entities.Server import ServerInterface
 
 
 class ConnectionInterface(abc.ABC):
@@ -23,12 +23,14 @@ class ConnectionInterface(abc.ABC):
     ConnectionInterface class
     """
 
-    @abc.abstractmethod
-    def connect(self, node: Node) -> None:
-        """
-        Start connection from node
+    url: str = ""
 
-        :param node: Node instance
+    @abc.abstractmethod
+    def connect(self, server: ServerInterface) -> None:
+        """
+        Start connection from server
+
+        :param server: Node instance
         :return:
         """
         raise NotImplementedError
@@ -50,3 +52,12 @@ class ConnectionInterface(abc.ABC):
         :return:
         """
         raise NotImplementedError
+
+
+class NetworkConnectionError(ConnectionError):
+    """
+    NetworkConnectionError class
+    """
+
+    def __init__(self):
+        super().__init__("Network connection error")
