@@ -73,3 +73,12 @@ class ConnectionsInterface(abc.ABC):
         :return:
         """
         raise NotImplementedError
+
+    @property
+    def datapod(self) -> ConnectionInterface:
+        """
+        Return a ConnectionInterface instance for the datapod
+
+        :return:
+        """
+        raise NotImplementedError
