@@ -18,22 +18,36 @@ import pickle
 from typing import Any, Iterable, List, Optional, Tuple, Type, Union
 from uuid import UUID
 
-from PyQt5.QtCore import QAbstractItemModel, QMimeData, QModelIndex, Qt, QVariant
-from PyQt5.QtGui import QFont, QIcon, QPixmap
+from PyQt5.QtCore import (
+    QAbstractItemModel,
+    QLocale,
+    QMimeData,
+    QModelIndex,
+    Qt,
+    QVariant,
+)
+from PyQt5.QtGui import QColor, QFont, QPixmap
 
 from tikka.domains.application import Application
 from tikka.domains.entities.account import Account
 from tikka.domains.entities.category import Category
-from tikka.domains.entities.identity import STATUS_VALIDATED
+from tikka.domains.entities.constants import AMOUNT_UNIT_KEY
+from tikka.domains.entities.identity import IdentityStatus
+from tikka.domains.entities.smith import SmithStatus
 from tikka.slots.pyqt.entities.constants import (
     ADDRESS_MONOSPACE_FONT_NAME,
     ICON_ACCOUNT_NO_WALLET,
     ICON_ACCOUNT_WALLET_LOCKED,
     ICON_ACCOUNT_WALLET_UNLOCKED,
-    ICON_IDENTITY,
+    ICON_IDENTITY_MEMBER,
+    ICON_IDENTITY_MEMBER_NOT_VALIDATED,
+    ICON_IDENTITY_NOT_MEMBER,
+    ICON_SMITH,
+    SELECTED_UNIT_PREFERENCES_KEY,
 )
 
-MemberStatusRole = Qt.UserRole + 1000
+WalletLockStatusRole = Qt.UserRole + 1000
+BalanceStyledRole = Qt.UserRole + 1001
 
 
 class TreeItem:
@@ -51,7 +65,7 @@ class TreeItem:
         self._parent = parent
         self._row = 0
 
-    def childCount(self):
+    def child_count(self):
         """
         Return number of children
 
@@ -66,7 +80,7 @@ class TreeItem:
         :param row: Row number
         :return:
         """
-        if 0 <= row < self.childCount():
+        if 0 <= row < self.child_count():
             return self._children[row]
         return None
 
@@ -86,7 +100,7 @@ class TreeItem:
         """
         return self._row
 
-    def insertChild(self, position: int, child: TreeItem) -> bool:
+    def insert_child(self, position: int, child: TreeItem) -> bool:
         """
         Insert child at position row
 
@@ -97,18 +111,18 @@ class TreeItem:
         self._children.insert(position, child)
         return True
 
-    def addChild(self, child: TreeItem) -> None:
+    def add_child(self, child: TreeItem) -> None:
         """
         Add a child to item
 
         :param child: TreeItem instance
         :return:
         """
-        child.setParent(self)
-        child.setRow(len(self._children))
+        child.set_parent(self)
+        child.set_row(len(self._children))
         self._children.append(child)
 
-    def setParent(self, parent: TreeItem) -> None:
+    def set_parent(self, parent: TreeItem) -> None:
         """
         Set parent item
 
@@ -117,7 +131,7 @@ class TreeItem:
         """
         self._parent = parent
 
-    def setRow(self, row: int) -> None:
+    def set_row(self, row: int) -> None:
         """
         Set row value
 
@@ -132,19 +146,51 @@ class AccountTreeModel(QAbstractItemModel):
     AccountTreeModel class that drives the population of tree display
     """
 
-    def __init__(self, application: Application):
+    def __init__(self, application: Application, locale: QLocale):
+        """
+        Init AccountTreeModel
+
+        :param application: Application instance
+        :param locale: QLocale instance
+        """
         super().__init__()
 
         self.application = application
         self._ = self.application.translator.gettext
 
+        # get parent widget locale to localize balance display
+        self.locale = locale
+
+        # calculate balance display by unit preference
+        unit_preference = self.application.repository.preferences.get(
+            SELECTED_UNIT_PREFERENCES_KEY
+        )
+        if unit_preference is not None:
+            self.amount = self.application.amounts.get_amount(unit_preference)
+        else:
+            self.amount = self.application.amounts.get_amount(AMOUNT_UNIT_KEY)
+
         # drag and drop mime-type
         self.mime_type = "application/vnd.text.list"
 
         # Number of column displayed, see self.data()
-        self._column_count = 2
+        self._column_count = 4
 
         self.root_item = TreeItem(None, None)
+        self.categories: List[Category] = []
+        self.accounts: List[Account] = []
+
+        self.display_identity_icon = {
+            IdentityStatus.UNCONFIRMED.value: QPixmap(
+                ICON_IDENTITY_MEMBER_NOT_VALIDATED
+            ),
+            IdentityStatus.UNVALIDATED.value: QPixmap(
+                ICON_IDENTITY_MEMBER_NOT_VALIDATED
+            ),
+            IdentityStatus.MEMBER.value: QPixmap(ICON_IDENTITY_MEMBER),
+            IdentityStatus.NOT_MEMBER.value: QPixmap(ICON_IDENTITY_NOT_MEMBER),
+            IdentityStatus.REVOKED.value: QPixmap(ICON_IDENTITY_NOT_MEMBER),
+        }
 
         self.init_data()
 
@@ -154,14 +200,67 @@ class AccountTreeModel(QAbstractItemModel):
 
         :return:
         """
+        # calculate balance display by unit preference
+        unit_preference = self.application.repository.preferences.get(
+            SELECTED_UNIT_PREFERENCES_KEY
+        )
+        if unit_preference is not None:
+            self.amount = self.application.amounts.get_amount(unit_preference)
+        else:
+            self.amount = self.application.amounts.get_amount(AMOUNT_UNIT_KEY)
+
         self.beginResetModel()
         self.root_item = TreeItem(None, None)
+        self.categories = self.application.categories.list_all()
+        self.accounts = self.application.accounts.get_list()
         self.recursive_append_children(None, self.root_item)
         self.endResetModel()
 
+    def account_list_by_category_id(self, category_id: Optional[UUID]) -> List[Account]:
+        """
+        Return all accounts in category_id
+
+        :param category_id: Category ID
+        :return:
+        """
+        result = []
+        for account in self.accounts:
+            # do not list derived accounts
+            if account.category_id is None and account.root is not None:
+                continue
+            if account.category_id == category_id:
+                result.append(account)
+
+        return result
+
+    def category_children(self, category_id: Optional[UUID]) -> List[Category]:
+        """
+        Return categories with parent category_id
+
+        :param category_id: Parent category ID
+        :return:
+        """
+        return [
+            category
+            for category in self.categories
+            if category.parent_id == category_id
+        ]
+
+    def get_derivation_accounts(self, address: str) -> List[Account]:
+        """
+        Return derived accounts from root address
+
+        :param address: Root account address
+        :return:
+        """
+        return sorted(
+            [account for account in self.accounts if account.root == address],
+            key=lambda account: account.path,  # type: ignore
+        )
+
     def recursive_append_children(
         self, element: Optional[Union[Category, Account]], item: TreeItem
-    ) -> None:
+    ) -> int:
         """
         Add children items from element to item
 
@@ -169,28 +268,40 @@ class AccountTreeModel(QAbstractItemModel):
         :param item: TreeItem instance
         :return:
         """
+        children_balance = 0
         if element is None or isinstance(element, Category):
             parent_category_id = None if element is None else element.id
-            # list of accounts in category
-            for account in self.application.accounts.list_by_category_id(
-                parent_category_id
-            ):
-                account_item = TreeItem(account, item)
-                item.addChild(account_item)
-                self.recursive_append_children(account, account_item)
 
             # list of categories in category
-            for category in self.application.categories.list(parent_category_id):
+            for category in self.category_children(parent_category_id):
                 category_item = TreeItem(category, self.root_item)
-                item.addChild(category_item)
-                self.recursive_append_children(category, category_item)
+                item.add_child(category_item)
+                children_balance += self.recursive_append_children(
+                    category, category_item
+                )
+
+            # list of accounts in category
+            for account in self.account_list_by_category_id(parent_category_id):
+                account_item = TreeItem(account, item)
+                item.add_child(account_item)
+                children_balance += self.recursive_append_children(
+                    account, account_item
+                )
+                if account.balance is not None:
+                    children_balance += account.balance
+
         elif isinstance(element, Account):
             # list of derivation from this account
-            for account in self.application.accounts.get_derivation_accounts(
-                element.address
-            ):
+            for account in self.get_derivation_accounts(element.address):
+                if account.balance is not None:
+                    children_balance += account.balance
                 account_item = TreeItem(account, item)
-                item.addChild(account_item)
+                item.add_child(account_item)
+
+        if isinstance(element, Category):
+            element.balance = children_balance
+
+        return children_balance
 
     def index(
         self, row: int, column: int, parent: QModelIndex = QModelIndex()
@@ -240,8 +351,8 @@ class AccountTreeModel(QAbstractItemModel):
         :return:
         """
         if parent.isValid():
-            return parent.internalPointer().childCount()
-        return self.root_item.childCount()
+            return parent.internalPointer().child_count()
+        return self.root_item.child_count()
 
     def columnCount(
         self, parent: QModelIndex = QModelIndex()  # pylint: disable=unused-argument
@@ -267,18 +378,104 @@ class AccountTreeModel(QAbstractItemModel):
             return data
 
         tree_item = index.internalPointer()
-        # display account address or category name in first column
+        # display account address or name or identity name#index or category name in first column
         # only this column is indented
         if index.column() == 0 and role in (Qt.DisplayRole, Qt.EditRole):
-            data = QVariant(tree_item.element.name)
+            if isinstance(tree_item.element, Account):
+                if tree_item.element.name is None:
+                    identity = self.application.identities.get_by_address(
+                        tree_item.element.address
+                    )
+                    if identity is not None:
+                        if identity.name is not None:
+                            data = QVariant(f"{identity.name}#{identity.index}")
+                        else:
+                            data = QVariant(f"#{identity.index}")
+                else:
+                    data = QVariant(tree_item.element.name)
+            else:
+                # category name
+                data = QVariant(tree_item.element.name)
 
+        # display wallet lock status icon for account in first column
+        if (
+            index.column() == 0
+            and role == WalletLockStatusRole
+            and isinstance(tree_item.element, Account)
+        ):
+            if self.application.wallets.exists(tree_item.element.address):
+                data = (
+                    QVariant(
+                        QPixmap(ICON_ACCOUNT_WALLET_UNLOCKED).scaled(
+                            16,
+                            18,
+                            aspectRatioMode=Qt.KeepAspectRatio,
+                            transformMode=Qt.SmoothTransformation,
+                        )
+                    )
+                    if self.application.wallets.is_unlocked(tree_item.element.address)
+                    else QVariant(
+                        QPixmap(ICON_ACCOUNT_WALLET_LOCKED).scaled(
+                            16,
+                            18,
+                            aspectRatioMode=Qt.KeepAspectRatio,
+                            transformMode=Qt.SmoothTransformation,
+                        )
+                    )
+                )
+            else:
+                data = QVariant(
+                    QPixmap(ICON_ACCOUNT_NO_WALLET).scaled(
+                        16,
+                        18,
+                        aspectRatioMode=Qt.KeepAspectRatio,
+                        transformMode=Qt.SmoothTransformation,
+                    )
+                )
+
+        # display icon of identity membership status
+        if (
+            index.column() == 0
+            and role == Qt.DecorationRole
+            and isinstance(tree_item.element, Account)
+        ):
+            identity = self.application.identities.get_by_address(
+                tree_item.element.address
+            )
+            if identity is not None:
+                data = QVariant(
+                    self.display_identity_icon[identity.status.value].scaled(
+                        16, 18, aspectRatioMode=Qt.KeepAspectRatio
+                    )
+                )
+                smith = self.application.smiths.get(identity.index)
+                if smith is not None and smith.status == SmithStatus.SMITH:
+                    data = QVariant(
+                        QPixmap(ICON_SMITH).scaled(
+                            16, 18, aspectRatioMode=Qt.KeepAspectRatio
+                        )
+                    )
+
+        # display account address
         if (
             index.column() == 1
             and role == Qt.DisplayRole
             and isinstance(tree_item.element, Account)
         ):
             data = QVariant(tree_item.element.address)
+        if (
+            index.column() == 1
+            and role == Qt.ToolTipRole
+            and isinstance(tree_item.element, Account)
+            and tree_item.element.legacy_v1 is True
+        ):
+            data = QVariant(
+                tree_item.element.get_v1_address(
+                    self.application.currencies.get_current().ss58_format
+                )
+            )
 
+        # font style
         if role == Qt.FontRole and isinstance(tree_item.element, Account):
             if index.column() == 1:
                 # display addresses in monospace font
@@ -286,44 +483,43 @@ class AccountTreeModel(QAbstractItemModel):
                 # if font is not found, choose equivalent monospace font on system
                 font.setStyleHint(QFont.Monospace)
                 # font.setBold(True)
+                # display root account with underline
+                if tree_item.element.root is None:
+                    font.setUnderline(True)
             else:
                 font = QFont()
-            # display root account with underline
-            if tree_item.element.root is None:
-                font.setUnderline(True)
+
             return QVariant(font)
 
-        # display wallet lock status icon for account in first column
+        # display account derivation path
         if (
-            index.column() == 0
-            and role == Qt.DecorationRole
+            index.column() == 2
+            and role == Qt.DisplayRole
             and isinstance(tree_item.element, Account)
         ):
-            if self.application.wallets.exists(tree_item.element.address):
-                data = (
-                    QVariant(QIcon(QPixmap(ICON_ACCOUNT_WALLET_UNLOCKED)))
-                    if self.application.wallets.is_unlocked(tree_item.element.address)
-                    else QVariant(QIcon(QPixmap(ICON_ACCOUNT_WALLET_LOCKED)))
-                )
-            else:
-                data = QVariant(QIcon(QPixmap(ICON_ACCOUNT_NO_WALLET)))
+            if tree_item.element.path is not None:
+                data = QVariant(tree_item.element.path)
 
-        # return icon of identity membership status
+        # display account balance
         if (
-            index.column() == 0
-            and role == MemberStatusRole
-            and isinstance(tree_item.element, Account)
+            index.column() == 3
+            and role == BalanceStyledRole
+            and tree_item.element.balance is not None
         ):
-            if tree_item.element.identity_index is not None:
-                identity = self.application.identities.get(
-                    tree_item.element.identity_index
+            data = QVariant(
+                self.locale.toCurrencyString(
+                    self.amount.value(tree_item.element.balance), self.amount.symbol()
                 )
-                if identity is not None and identity.status == STATUS_VALIDATED:
-                    data = QVariant(
-                        QPixmap(ICON_IDENTITY).scaled(
-                            16, 16, aspectRatioMode=Qt.KeepAspectRatio
-                        )
+            )
+
+        if role == Qt.TextColorRole and index.column() == 0:
+            if isinstance(tree_item.element, Account):
+                if tree_item.element.name is None:
+                    identity = self.application.identities.get_by_address(
+                        tree_item.element.address
                     )
+                    if identity is not None:
+                        data = QVariant(QColor("blue"))
 
         return data
 
@@ -394,7 +590,7 @@ class AccountTreeModel(QAbstractItemModel):
         elif isinstance(parent_item.element, Category):
             parent_id = parent_item.element.id
         category = self.application.categories.create("", parent_id)
-        success = parent_item.insertChild(row, TreeItem(category, parent_item))
+        success = parent_item.insert_child(row, TreeItem(category, parent_item))
         self.application.categories.repository.add(category)
         self.endInsertRows()
         return success
