@@ -357,7 +357,11 @@ class AccountTreeWidget(QWidget, Ui_AccountTreeWidget):
             amount = self.application.amounts.get_amount(unit_preference)
         else:
             amount = self.application.amounts.get_amount(AMOUNT_UNIT_KEY)
-        total_balance = self.application.accounts.get_total_balance()
+        total_balance = sum(
+            account.balance
+            for account in self.application.accounts.get_list()
+            if account.balance is not None
+        )
         self.totalBalanceValueLabel.setText(
             self.locale().toCurrencyString(
                 amount.value(total_balance),
@@ -474,9 +478,7 @@ class AccountTreeWidget(QWidget, Ui_AccountTreeWidget):
         """
         accounts = self.application.accounts.get_list()
         try:
-            self.application.accounts.network_update_balances(
-                self.application.accounts.get_list()
-            )
+            self.application.accounts.network_update_balances(accounts)
         except Exception as exception:
             logging.exception(exception)
             self.error_message = str(exception)
