@@ -59,7 +59,9 @@ class NodePopupMenu(QMenu):
         if (
             not self.node.url == self.application.nodes.get_current_url()
             and self.node.url
-            not in self.application.currencies.get_entry_point_urls()["rpc"]
+            not in self.application.currencies.get_entry_point_urls()[
+                self.application.nodes.CONFIG_NODES_ENDPOINTS_KEYWORD
+            ]
         ):
             forget_node_action = self.addAction(self._("Forget server"))
             forget_node_action.triggered.connect(self.delete_node)
@@ -90,6 +92,11 @@ class NodePopupMenu(QMenu):
         """
         response_button = self.confirm_delete_node(self.node)
         if response_button == QMessageBox.Yes:
+            if (
+                self.application.nodes.get_current_url() == self.node.url
+                and self.application.connections.node.is_connected()
+            ):
+                self.application.connections.node.disconnect()
             self.application.nodes.delete(self.node.url)
             self.application.event_dispatcher.dispatch_event(
                 NodesEvent(NodesEvent.EVENT_TYPE_LIST_CHANGED)
