@@ -17,17 +17,18 @@ import sys
 from collections import OrderedDict
 from typing import Optional
 
+from mnemonic import Mnemonic
 from PyQt5.QtGui import QFont
-from PyQt5.QtWidgets import QApplication, QDialog, QWidget
-from substrateinterface import Keypair, KeypairType
+from PyQt5.QtWidgets import QApplication, QButtonGroup, QDialog, QWidget
 
 from tikka.domains.application import Application
+from tikka.domains.entities.account import AccountCryptoType
 from tikka.domains.entities.constants import (
     DATA_PATH,
-    DERIVATION_PATH_TRANSPARENT_DEFAULT,
     MNEMONIC_WORDS_LENGTH,
     WALLETS_PASSWORD_LENGTH,
 )
+from tikka.libs.keypair import Keypair
 from tikka.libs.secret import generate_alphabetic
 from tikka.slots.pyqt.entities.constants import ADDRESS_MONOSPACE_FONT_NAME
 from tikka.slots.pyqt.resources.gui.windows.account_create_rc import (
@@ -40,6 +41,17 @@ class AccountCreateWindow(QDialog, Ui_AccountCreateDialog):
     AccountCreateWindow class
     """
 
+    language_code_map = {
+        "en": "english",
+        "fr": "french",
+        "zh-hans": "chinese_simplified",
+        "zh-hant": "chinese_traditional",
+        "it": "italian",
+        "ja": "japanese",
+        "ko": "korean",
+        "es": "spanish",
+    }
+
     def __init__(self, application: Application, parent: Optional[QWidget] = None):
         """
         Init create account window
@@ -73,7 +85,18 @@ class AccountCreateWindow(QDialog, Ui_AccountCreateDialog):
                 self.application.config.get("language")[:2]
             )
         )
-        self.derivationValueLabel.setText(DERIVATION_PATH_TRANSPARENT_DEFAULT)
+        self.language_code = self.mnemonicLanguageComboBox.currentData()
+
+        self.cryptoTypeGroup = QButtonGroup(self)
+        self.cryptoTypeGroup.addButton(self.ed25519RadioButton)
+        self.cryptoTypeGroup.addButton(self.sr25519RadioButton)
+        self.ed25519RadioButton.setChecked(True)
+        self.crypto_type = (
+            AccountCryptoType.ED25519
+            if self.ed25519RadioButton.isChecked()
+            else AccountCryptoType.SR25519
+        )
+
         monospace_font = QFont(ADDRESS_MONOSPACE_FONT_NAME)
         monospace_font.setStyleHint(QFont.Monospace)
         self.addressValueLabel.setFont(monospace_font)
@@ -85,8 +108,9 @@ class AccountCreateWindow(QDialog, Ui_AccountCreateDialog):
         # events
         self.changeButton.clicked.connect(self._generate_mnemonic_and_address)
         self.mnemonicLanguageComboBox.currentIndexChanged.connect(
-            self._generate_mnemonic_and_address
+            self._on_mnemonic_language_combo_box_index_changed
         )
+        self.cryptoTypeGroup.buttonClicked.connect(self.on_crypto_type_changed)
         self.passwordChangeButton.clicked.connect(self._generate_wallet_password)
         self.buttonBox.accepted.connect(self.on_accepted_button)
         self.buttonBox.rejected.connect(self.close)
@@ -98,24 +122,64 @@ class AccountCreateWindow(QDialog, Ui_AccountCreateDialog):
         self._generate_mnemonic_and_address()
         self._generate_wallet_password()
 
+    def _on_mnemonic_language_combo_box_index_changed(self):
+        """
+        Triggered when user change mnemonic language selector
+
+        :return:
+        """
+        old_mnemonic = self.mnemonicLineEdit.text()
+
+        # use mnemonic utilities to get entropy from user language
+        mnemonic_util = Mnemonic(self.language_code_map[self.language_code])
+        entropy = mnemonic_util.to_entropy(mnemonic_util.normalize_string(old_mnemonic))
+
+        self.language_code = self.mnemonicLanguageComboBox.currentData()
+
+        # get mnemonic in new language from entropy
+        mnemonic_util = Mnemonic(self.language_code_map[self.language_code])
+        mnemonic = mnemonic_util.to_mnemonic(entropy)
+
+        self.mnemonicLineEdit.setText(mnemonic)
+
     def _generate_mnemonic_and_address(self):
         """
         Generate mnemonic passphrase and address
 
         :return:
         """
-        language_code = self.mnemonicLanguageComboBox.currentData()
-        mnemonic = Keypair.generate_mnemonic(MNEMONIC_WORDS_LENGTH, language_code)
-        address = Keypair.create_from_uri(
-            suri=mnemonic + DERIVATION_PATH_TRANSPARENT_DEFAULT,
-            ss58_format=self.application.currencies.get_current().ss58_format,
-            crypto_type=KeypairType.SR25519,
-            language_code=language_code,
-        ).ss58_address
-
+        mnemonic = Keypair.generate_mnemonic(MNEMONIC_WORDS_LENGTH, self.language_code)
         self.mnemonicLineEdit.setText(mnemonic)
+
+        self._generate_address()
+
+    def _generate_address(self):
+        """
+        Generate keypair and address
+
+        :return:
+        """
+        address = Keypair.create_from_uri(
+            suri=self.mnemonicLineEdit.text(),
+            ss58_format=self.application.currencies.get_current().ss58_format,
+            crypto_type=self.crypto_type,
+            language_code=self.language_code,
+        ).ss58_address
         self.addressValueLabel.setText(address)
 
+    def on_crypto_type_changed(self):
+        """
+        Triggered when user click on key type radio button
+
+        :return:
+        """
+        self.crypto_type = (
+            AccountCryptoType.ED25519
+            if self.ed25519RadioButton.isChecked()
+            else AccountCryptoType.SR25519
+        )
+        self._generate_address()
+
     def _generate_wallet_password(self):
         """
         Generate new password for wallet encryption in UI
@@ -148,7 +212,7 @@ class AccountCreateWindow(QDialog, Ui_AccountCreateDialog):
 
         # create derived account + wallet (and the read-only root account)
         self.application.accounts.create_new_account(
-            mnemonic, language_code, DERIVATION_PATH_TRANSPARENT_DEFAULT, name, password
+            mnemonic, language_code, "", self.crypto_type, name, password
         )
 
         # close window
