@@ -256,6 +256,12 @@ class TransferWindow(QDialog, Ui_TransferDialog):
         self.send_tranfer_to_network_async_qworker.finished.connect(
             self._on_finished_send_transfer_to_network
         )
+        self.fetch_balances_from_network_async_qworker = AsyncQWorker(
+            self.fetch_balances_from_network, self.mutex, self
+        )
+        self.fetch_balances_from_network_async_qworker.finished.connect(
+            self._on_finished_fetch_balances_from_network
+        )
 
         # Receiver is a history account, not stored...
         if (
@@ -297,11 +303,15 @@ class TransferWindow(QDialog, Ui_TransferDialog):
                 self.application.accounts.get_by_address(self.recipient_account.address)
                 is None
             ):
-                self.recipient_account.balance = (
-                    self.application.accounts.network_get_balance(
-                        self.recipient_account.address
-                    )
+                recipient_balance = self.application.accounts.network_get_balance(
+                    self.recipient_account.address
                 )
+                if recipient_balance is not None:
+                    self.recipient_account.balance = recipient_balance.total
+                    self.recipient_account.balance_available = (
+                        recipient_balance.available
+                    )
+                    self.recipient_account.balance_reserved = recipient_balance.reserved
             else:
                 self.recipient_account = (
                     self.application.accounts.network_update_balance(
@@ -531,6 +541,19 @@ class TransferWindow(QDialog, Ui_TransferDialog):
                         amount.value(self.sender_account.balance), amount.symbol()
                     )
                 )
+                display_sender_reserved_balance = self.locale().toCurrencyString(
+                    amount.value(self.sender_account.balance_reserved), amount.symbol()
+                )
+                self.senderBalanceReservedValueLabel.setText(
+                    f"[-{display_sender_reserved_balance}]"
+                )
+
+                self.amountDoubleSpinBox.setMaximum(
+                    amount.value(
+                        self.sender_account.balance
+                        - self.sender_account.balance_reserved
+                    )
+                )
 
         if self.recipient_account is not None:
             if self.recipient_account.balance is None:
@@ -677,6 +700,23 @@ class TransferWindow(QDialog, Ui_TransferDialog):
         if sender_keypair is None:
             return
 
+        # if amount needs unclaimed UDs funds...
+        if blockchain_value > self.sender_account.balance_available:
+            identity = self.application.identities.get_by_address(
+                self.sender_account.address
+            )
+            if identity is not None:
+                self.errorLabel.setStyleSheet("color: green;")
+                self.errorLabel.setText(self._("Claiming Universal Dividends..."))
+                # get unclaimed UDs
+                try:
+                    self.application.identities.network_claim_uds(sender_keypair)
+                except Exception as exception:
+                    self.transfer_success = False
+                    self.errorLabel.setStyleSheet("color: red;")
+                    self.errorLabel.setText(self._(str(exception)))
+                    logging.exception(exception)
+
         try:
             if comment == "":
                 extrinsic_receipt = self.application.transfers.network_send(
@@ -720,8 +760,25 @@ class TransferWindow(QDialog, Ui_TransferDialog):
         """
         self.loaderIconLabel.hide()
         self.sendButton.setDisabled(False)
-        self.fetch_sender_balance_from_network_async_qworker.start()
-        self.fetch_recipient_balance_from_network_async_qworker.start()
+        self.fetch_balances_from_network_async_qworker.start()
+
+    def fetch_balances_from_network(self):
+        """
+        Fetch sender and recipient balances from network
+
+        :return:
+        """
+        self.fetch_sender_balance_from_network()
+        self.fetch_recipient_balance_from_network()
+
+    def _on_finished_fetch_balances_from_network(self):
+        """
+        Triggered when async request fetch_balances_from_network is finished
+
+        :return:
+        """
+        self._on_finished_fetch_sender_balance_from_network()
+        self._on_finished_fetch_recipient_balance_from_network()
 
 
 if __name__ == "__main__":
