@@ -120,9 +120,12 @@ class V1AccountImportWizardWindow(QWizard, Ui_importAccountV1Wizard):
                 AccountsRepositoryInterface.COLUMN_LEGACY_V1: True,
             }
         ):
+            password_address = (
+                account.root if account.root is not None else account.address
+            )
             # only accounts with password (user owns it)
             if account.balance is not None and self.application.passwords.exists(
-                account.address
+                password_address
             ):
                 account_label = (
                     account.name if account.name is not None else account.address
@@ -252,8 +255,11 @@ class V1AccountImportWizardWindow(QWizard, Ui_importAccountV1Wizard):
                 continue
             if self.source_account.address == account.address:
                 continue
+            password_address = (
+                account.root if account.root is not None else account.address
+            )
             # only accounts with password (user owns it)
-            if self.application.passwords.exists(account.address):
+            if self.application.passwords.exists(password_address):
                 self.destinationAccountComboBox.addItem(
                     account.name if account.name is not None else account.address,
                     userData=account.address,
