@@ -17,14 +17,16 @@ import sys
 from collections import OrderedDict
 from typing import Optional
 
+from mnemonic import Mnemonic
+from mnemonic.mnemonic import ConfigurationError
 from PyQt5.QtCore import QTimer
 from PyQt5.QtGui import QFont
 from PyQt5.QtWidgets import QApplication, QDialog, QLineEdit, QMessageBox, QWidget
-from substrateinterface import Keypair, KeypairType
 
 from tikka.domains.application import Application
-from tikka.domains.entities.account import Account
+from tikka.domains.entities.account import Account, AccountCryptoType
 from tikka.domains.entities.constants import DATA_PATH, WALLETS_PASSWORD_LENGTH
+from tikka.libs.keypair import Keypair, KeypairType
 from tikka.libs.secret import generate_alphabetic, sanitize_mnemonic_string
 from tikka.slots.pyqt.entities.constants import (
     ADDRESS_MONOSPACE_FONT_NAME,
@@ -40,6 +42,17 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
     WalletRestoreWindow class
     """
 
+    language_code_map = {
+        "english": "en",
+        "french": "fr",
+        "chinese_simplified": "zh-hans",
+        "chinese_traditional": "zh-hant",
+        "italian": "it",
+        "japanese": "ja",
+        "korean": "ko",
+        "spanish": "es",
+    }
+
     def __init__(
         self,
         application: Application,
@@ -69,7 +82,7 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         self.addressValueLabel.setFont(monospace_font)
 
         # Mnemonic language selector translated
-        mnemonic_language_selector = OrderedDict(
+        self.mnemonic_language_displayed = OrderedDict(
             [
                 ("en", self._("English")),
                 ("fr", self._("French")),
@@ -81,13 +94,6 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
                 ("es", self._("Spanish")),
             ]
         )
-        for language_code, language_name in mnemonic_language_selector.items():
-            self.mnemonicLanguageComboBox.addItem(language_name, userData=language_code)
-        self.mnemonicLanguageComboBox.setCurrentIndex(
-            self.mnemonicLanguageComboBox.findData(
-                self.application.config.get("language")[:2]
-            )
-        )
 
         # buttons
         self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
@@ -95,9 +101,6 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         # events
         self.mnemonicLineEdit.textChanged.connect(self._on_mnemonic_changed)
         self.showButton.clicked.connect(self.on_show_button_clicked)
-        self.mnemonicLanguageComboBox.currentIndexChanged.connect(
-            self._on_mnemonic_changed
-        )
         self.passwordChangeButton.clicked.connect(self._generate_wallet_password)
         self.buttonBox.accepted.connect(self.on_accepted_button)
         self.buttonBox.rejected.connect(self.close)
@@ -108,7 +111,7 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
 
         # fill form
         self.storedPasswordFrame.hide()
-        self.derivationValueLabel.setText(self.account.path)
+        self.derivationValueLabel.setText(self.account.path or "")
         self.addressValueLabel.setText(self.account.address)
         self.nameValueLabel.setText(self.account.name)
         self._generate_wallet_password()
@@ -143,13 +146,27 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
 
         self.errorLabel.setText("")
         mnemonic = sanitize_mnemonic_string(self.mnemonicLineEdit.text())
-        language_code = self.mnemonicLanguageComboBox.currentData()
+        try:
+            self.language_code = self.language_code_map[
+                Mnemonic.detect_language(mnemonic)
+            ]
+        except ConfigurationError as exception:
+            logging.exception(exception)
+            self.addressValueLabel.setText("")
+            self.errorLabel.setText(self._("Language not detected"))
+            self.mnemonicLanguageValueLabel.setText("")
+            self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
+            return False
 
-        if not Keypair.validate_mnemonic(mnemonic, language_code):
+        if not Keypair.validate_mnemonic(mnemonic, self.language_code):
             self.errorLabel.setText(self._("Mnemonic or language not valid!"))
             self.buttonBox.button(self.buttonBox.Ok).setEnabled(False)
             return False
 
+        self.mnemonicLanguageValueLabel.setText(
+            self.mnemonic_language_displayed[self.language_code]
+        )
+
         derivation_path = "" if self.account.path is None else self.account.path
         suri = mnemonic + derivation_path
         if suri == "":
@@ -158,8 +175,8 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
             address = Keypair.create_from_uri(
                 suri,
                 ss58_format=self.application.currencies.get_current().ss58_format,
-                crypto_type=KeypairType.SR25519,
-                language_code=language_code,
+                crypto_type=self.account.crypto_type or KeypairType.ED25519,
+                language_code=self.language_code,
             ).ss58_address
         except Exception as exception:
             logging.exception(exception)
@@ -178,8 +195,8 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         # if password exists, hide the password field
         root_keypair = Keypair.create_from_mnemonic(
             mnemonic=mnemonic,
-            language_code=language_code,
-            crypto_type=KeypairType.SR25519,
+            language_code=self.language_code,
+            crypto_type=self.account.crypto_type or KeypairType.ED25519,
             ss58_format=self.application.currencies.get_current().ss58_format,
         )
         if (
@@ -232,7 +249,6 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         mnemonic = sanitize_mnemonic_string(self.mnemonicLineEdit.text())
         derivation_path = "" if self.account.path is None else self.account.path
         suri = mnemonic + derivation_path
-        language_code = self.mnemonicLanguageComboBox.currentData()
 
         # generated inputs
         password = self.passwordLineEdit.text()
@@ -240,8 +256,8 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         # root keypair for password
         root_keypair = Keypair.create_from_mnemonic(
             mnemonic=mnemonic,
-            language_code=language_code,
-            crypto_type=KeypairType.SR25519,
+            language_code=self.language_code,
+            crypto_type=self.account.crypto_type,
             ss58_format=self.application.currencies.get_current().ss58_format,
         )
         # if password exists for root account...
@@ -260,14 +276,14 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
         # update all existing wallets for this root account and his derivation with new password
         if self.reset_password:
             self.application.accounts.reset_password(
-                root_keypair, mnemonic, language_code, password
+                root_keypair, mnemonic, self.language_code, password
             )
 
         # create keypair from mnemonic to get seed as hexadecimal
         keypair = Keypair.create_from_uri(
             suri,
-            language_code=language_code,
-            crypto_type=KeypairType.SR25519,
+            language_code=self.language_code,
+            crypto_type=self.account.crypto_type,
             ss58_format=self.application.currencies.get_current().ss58_format,
         )
 
@@ -296,7 +312,12 @@ class WalletRestoreWindow(QDialog, Ui_WalletRestoreDialog):
 if __name__ == "__main__":
     qapp = QApplication(sys.argv)
     application_ = Application(DATA_PATH)
-    account_ = Account(
-        "5D2YjANfzuGvJWc3gykeFokJoboi57WAqbaVdo8VJzduFNsB", path="//2", name="test name"
+    account_ = application_.accounts.create_new_account(
+        "album cute glance oppose hub fury strategy health dust rebuild trophy magic",
+        "en",
+        derivation="//2",
+        crypto_type=AccountCryptoType.ED25519,
+        name="test name",
+        password="aaaaaa",
     )
     WalletRestoreWindow(application_, account_).exec_()
